@@ -24,7 +24,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.4 1997/10/19 22:03:52 windl Exp $ */
+ * $Id: enable_pps.c,v 1.5 1998/02/10 10:55:50 windl Exp $ */
 #include	<unistd.h>
 #include	<time.h>
 #include	<stdlib.h>
@@ -37,7 +37,7 @@
 #include	<sys/ioctl.h>
 #include	<termios.h>
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.4 1997/10/19 22:03:52 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.5 1998/02/10 10:55:50 windl Exp $";
 
 static	char	polarity	= 'p';	/* p[ositive] | n[egative] | 0) */
 
@@ -203,7 +203,7 @@ void	restart(struct timex *txp)
 /* do offset adjustments. expects offset within bounds */
 static	void	pll_adj_offset(struct timex *txp)
 {
-	static	last_adj_time;
+	static	time_t last_adj_time;
 	time_t	t = time(NULL);
 	long	offset = txp->offset;
 
